"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.definition = {
    site: 'nordichd',
    name: 'NORDiCHD',
    description: 'NORDiCHD is a Mixed Nordic HD Tracker which Encodes a lot of Tv shows and Movies',
    language: 'en-US',
    type: 'private',
    encoding: 'UTF-8',
    links: ['http://www.nordichd.eu/'],
    caps: {
        categorymappings: [
            { id: '1', cat: 'Movies', desc: 'Movies' },
            { id: '14', cat: 'Movies/3D', desc: 'Movie 3D' },
            { id: '16', cat: 'Movies/BluRay', desc: 'Movie Blu-Ray' },
            { id: '17', cat: 'Movies/HD', desc: 'Movie HD-1080p' },
            { id: '31', cat: 'Movies/HD', desc: 'Movie HD-720p' },
            { id: '32', cat: 'Movies/SD', desc: 'Movie SD' },
            { id: '33', cat: 'Movies/BluRay', desc: 'Movie BD-Rip' },
            { id: '34', cat: 'Movies/BluRay', desc: 'Movie BR-Rip' },
            { id: '35', cat: 'TV/HD', desc: 'HDTV' },
            { id: '36', cat: 'Movies', desc: 'Movie Remux' },
            { id: '37', cat: 'Movies/WEBDL', desc: 'Movie WEB-DL' },
            { id: '46', cat: 'TV/Documentary', desc: 'Documentary' },
            { id: '6', cat: 'Movies', desc: 'Internal' },
            { id: '18', cat: 'Movies/3D', desc: 'Internal 3D' },
            { id: '19', cat: 'Movies/BluRay', desc: 'Internal Blu-Ray' },
            { id: '38', cat: 'Movies/HD', desc: 'Internal HD-1080p' },
            { id: '39', cat: 'Movies/HD', desc: 'Internal HD-720p' },
            { id: '40', cat: 'Movies/SD', desc: 'Internal SD' },
            { id: '41', cat: 'Movies/BluRay', desc: 'Internal BD-Rip' },
            { id: '42', cat: 'Movies/BluRay', desc: 'Internal BR-Rip' },
            { id: '43', cat: 'TV/HD', desc: 'Internal HDTV' },
            { id: '44', cat: 'Movies', desc: 'Internal Remux' },
            { id: '45', cat: 'Movies/WEBDL', desc: 'Internal WEB-DL' },
            { id: '47', cat: 'TV/Documentary', desc: 'Internal Documentary' },
            { id: '7', cat: 'Audio', desc: 'Music' },
            { id: '20', cat: 'Audio/Video', desc: 'Music Video' },
            { id: '21', cat: 'Audio/MP3', desc: 'Music Mp3' },
        ],
        modes: {
            search: ['q'],
            'tv-search': ['q', 'season', 'ep'],
            'movie-search': ['q'],
            'music-search': ['q'],
        },
    },
    settings: [
        { name: 'username', type: 'text', label: 'Username' },
        { name: 'password', type: 'password', label: 'Password' },
        {
            name: 'sort',
            type: 'select',
            label: 'Sort requested from site',
            default: 'added',
            options: { added: 'created', seeders: 'seeders', size: 'size' },
        },
        {
            name: 'type',
            type: 'select',
            label: 'Order requested from site',
            default: 'desc',
            options: { desc: 'desc', asc: 'asc' },
        },
    ],
    login: {
        path: '?p=home&pid=1',
        method: 'form',
        form: 'form#sls_form',
        submitpath: 'ajax/login.php',
        inputs: {
            action: 'login',
            loginbox_membername: '{{ .Config.username }}',
            loginbox_password: '{{ .Config.password }}',
            loginbox_remember: 1,
        },
        selectorinputs: {
            securitytoken: {
                selector: 'script:contains("stKey: ")',
                filters: [{ name: 'regexp', args: 'stKey: "(.+?)",' }],
            },
        },
        error: [{ selector: 'div.error' }, { selector: ':contains("-ERROR-")' }],
        test: { path: '?p=home&pid=1', selector: 'div#member_info_bar' },
    },
    search: {
        paths: [{ path: '/' }],
        inputs: {
            p: 'torrents',
            pid: 10,
            $raw: '{{ range .Categories }}&cid[]={{.}}{{end}}',
            keywords: '{{ .Keywords }}',
            search_type: 'name',
            'sortOptions[sortBy]': '{{ .Config.sort }}',
            'sortOptions[sortOrder]': '{{ .Config.type }}',
        },
        rows: { selector: 'div.torrent-box[id^="torrent_"]' },
        fields: {
            title: {
                selector: 'a[href*="?p=torrents&pid=10&action=details&tid="]',
            },
            details: {
                selector: 'a[href*="?p=torrents&pid=10&action=details&tid="]',
                attribute: 'href',
            },
            category: {
                selector: 'a[href*="?p=torrents&pid=10&cid="]',
                attribute: 'href',
                filters: [{ name: 'querystring', args: 'cid' }],
            },
            download: {
                selector: 'a[href*="?p=torrents&pid=10&action=download&tid="]',
                attribute: 'href',
            },
            banner: {
                optional: true,
                selector: 'a[href*="data/torrents/torrent_images/"]',
                attribute: 'href',
            },
            size: { selector: 'a[rel="torrent_size"]' },
            grabs: { selector: 'a[rel="times_completed"]' },
            seeders: { selector: 'a[rel="torrent_seeders"]' },
            leechers: { selector: 'a[rel="torrent_leechers"]' },
            date: {
                selector: 'div.torrentOwner:contains("-")',
                optional: true,
                filters: [
                    { name: 'regexp', args: 'Uploaded (.+?) by' },
                    { name: 'dateparse', args: '02-01-2006 15:04' },
                ],
            },
            downloadvolumefactor: {
                case: { 'img[src$="/torrent_free.png"]': 0.5, '*': 1 },
            },
            uploadvolumefactor: { case: { '*': 1 } },
        },
    },
    source: 'jackett',
};
